aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--samplecode/SampleApp.cpp2
-rw-r--r--samplecode/SampleText.cpp3
-rw-r--r--src/core/SkRegion.cpp226
-rw-r--r--src/ports/SkFontHost_mac_coretext.cpp94
-rw-r--r--xcode/effects/effects.xcodeproj/project.pbxproj7
-rw-r--r--xcode/maccore/maccore.xcodeproj/project.pbxproj17
-rw-r--r--xcode/sampleapp/SampleApp.xcodeproj/project.pbxproj214
7 files changed, 257 insertions, 306 deletions
diff --git a/samplecode/SampleApp.cpp b/samplecode/SampleApp.cpp
index 3947bdc832..2bd1fe032a 100644
--- a/samplecode/SampleApp.cpp
+++ b/samplecode/SampleApp.cpp
@@ -13,7 +13,7 @@
extern SkView* create_overview(int, const SkViewFactory[]);
-//#define SK_SUPPORT_GL
+#define SK_SUPPORT_GL
#ifdef SK_SUPPORT_GL
#include <AGL/agl.h>
diff --git a/samplecode/SampleText.cpp b/samplecode/SampleText.cpp
index 153726ac84..14b3d80cc5 100644
--- a/samplecode/SampleText.cpp
+++ b/samplecode/SampleText.cpp
@@ -488,6 +488,7 @@ protected:
virtual void onDraw(SkCanvas* canvas)
{
+ inval(NULL);
if (false)
{
canvas->translate(SkIntToScalar(480), 0);
@@ -754,7 +755,7 @@ protected:
}
}
if (gHints[index].fFlushCache) {
- SkGraphics::SetFontCacheUsed(0);
+// SkGraphics::SetFontCacheUsed(0);
}
}
diff --git a/src/core/SkRegion.cpp b/src/core/SkRegion.cpp
index 376f79c255..ce4252394c 100644
--- a/src/core/SkRegion.cpp
+++ b/src/core/SkRegion.cpp
@@ -555,230 +555,16 @@ void SkRegion::translate(int dx, int dy, SkRegion* dst) const
///////////////////////////////////////////////////////////////////////////////
-#include "SkChunkAlloc.h"
-#include "SkTDArray.h"
-#include "SkTSearch.h"
-#include "SkTemplates.h"
-
-template <typename T> int SkTCmp2Int(const T& a, const T& b) {
- return (a < b) ? -1 : ((b < a) ? 1 : 0);
-}
-
-struct VEdge {
- int32_t fX;
- int fDir; // 1, -1
-};
-
-static VEdge* append_rect(VEdge* edge, const SkIRect& r) {
- edge[0].fX = r.fLeft;
- edge[0].fDir = -1;
- edge[1].fX = r.fRight;
- edge[1].fDir = 1;
- return edge + 2;
-}
-
-class Accumulator {
-public:
- Accumulator(SkRegion::RunType top, int numRects);
- ~Accumulator() {}
-
- void append(int32_t bottom, const VEdge edge[], int count);
-
- int count() const { return fTotalCount; }
- void copyTo(SkRegion::RunType dst[]);
-
-private:
- struct Row {
- SkRegion::RunType* fPtr;
- SkRegion::RunType fBottom;
- int fCount; // just [L R] count
- };
- SkChunkAlloc fAlloc;
- SkTDArray<Row> fRows;
- SkRegion::RunType fTop;
- int fTotalCount;
-};
-
-Accumulator::Accumulator(SkRegion::RunType top, int numRects)
- : fAlloc((1 + numRects * 2 + 1) * sizeof(int32_t)) {
- fTop = top;
- fTotalCount = 2; // Top + final sentinel
-}
-
-static int union_edges(SkRegion::RunType dst[], const VEdge edge[], int count) {
- if (0 == count) {
- return 0;
- }
-
- SkRegion::RunType* startDst = dst;
- const VEdge* stop = edge + count;
-
- SkRegion::RunType currR;
- int dir = edge->fDir;
-
- *dst++ = edge->fX; // initial L
- while (++edge < stop) {
- int prevDir = dir;
- dir += edge->fDir;
- if (0 == dir) { // we finished an interval
- currR = edge->fX;
- } else if (0 == prevDir && edge->fX > currR) {
- *dst++ = currR;
- *dst++ = edge->fX;
- }
- }
- SkASSERT(0 == dir);
- *dst++ = currR;
- SkDEBUGCODE(int resultCount = dst - startDst;)
- SkASSERT(resultCount <= count && (resultCount & 1) == 0);
- return dst - startDst;
-}
-
-void Accumulator::append(int32_t bottom, const VEdge edge[], int count) {
- SkASSERT((count & 1) == 0);
-
- size_t size = count * sizeof(SkRegion::RunType);
- int32_t* row = (SkRegion::RunType*)fAlloc.allocThrow(size);
- int rowCount = union_edges(row, edge, count);
-
- Row* r = fRows.count() ? &fRows[fRows.count() - 1] : NULL;
- if (r && (r->fCount == rowCount) &&
- !memcmp(r->fPtr, row,
- rowCount * sizeof(SkRegion::RunType))) {
- r->fBottom = bottom; // update bottom
- fAlloc.unalloc(row);
- } else {
- Row* r = fRows.append();
- r->fPtr = row;
- r->fBottom = bottom;
- r->fCount = rowCount;
- fTotalCount += 1 + rowCount + 1;
- }
-}
-
-void Accumulator::copyTo(SkRegion::RunType dst[]) {
- SkDEBUGCODE(SkRegion::RunType* startDst = dst;)
-
- *dst++ = fTop;
-
- const Row* curr = fRows.begin();
- const Row* stop = fRows.end();
- while (curr < stop) {
- *dst++ = curr->fBottom;
- memcpy(dst, curr->fPtr, curr->fCount * sizeof(SkRegion::RunType));
- dst += curr->fCount;
- *dst++ = SkRegion::kRunTypeSentinel;
- curr += 1;
- }
- *dst++ = SkRegion::kRunTypeSentinel;
- SkASSERT(dst - startDst == fTotalCount);
-}
-
-/////////////
-
-struct RNode {
- RNode* fNext;
- const SkIRect* fRect;
-};
-
-static int compare_rnode_top(const void* e0, const void* e1) {
- const RNode* r0 = static_cast<const RNode*>(e0);
- const RNode* r1 = static_cast<const RNode*>(e1);
- return SkTCmp2Int<int32_t>(r0->fRect->fTop, r1->fRect->fTop);
-}
-
-static int compare_vedge(const void* e0, const void* e1) {
- const VEdge* v0 = static_cast<const VEdge*>(e0);
- const VEdge* v1 = static_cast<const VEdge*>(e1);
- return SkTCmp2Int<int32_t>(v0->fX, v1->fX);
-}
-
bool SkRegion::setRects(const SkIRect rects[], int count) {
if (0 == count) {
- return this->setEmpty();
- }
- if (1 == count) {
- return this->setRect(rects[0]);
- }
-
- int i;
- SkIRect sentinelRect = SkIRect::MakeLTRB(kRunTypeSentinel, kRunTypeSentinel,
- kRunTypeSentinel, kRunTypeSentinel);
-
- SkAutoTArray<RNode> nodeStorage(count + 1);
- RNode* nodes = nodeStorage.get();
- for (i = 0; i < count; i++) {
- if (!rects[i].isEmpty()) {
- nodes->fRect = &rects[i];
- nodes += 1;
- }
- }
- // recompute count, since we may have skipped empty rects
- count = nodes - nodeStorage.get();
- nodes = nodeStorage.get();
- // we are now done with the original rects[] parameter
- SkDEBUGCODE(rects = NULL;)
-
- SkQSort(nodes, count, sizeof(nodes[0]), compare_rnode_top);
- for (i = 0; i < count; i++) {
- nodes[i].fNext = &nodes[i + 1];
- }
- nodes[count].fNext = NULL;
- nodes[count].fRect = &sentinelRect;
-
- SkAutoTArray<VEdge> edgeStorage(count * 2);
-
- VEdge* edges = edgeStorage.get();
- RNode* nodeHead = nodeStorage.get();
-
- int32_t currY = nodeHead->fRect->fTop;
- Accumulator accum(currY, count);
-
- while (nodeHead->fNext) {
- RNode* node = nodeHead;
-
- int32_t nextY = kRunTypeSentinel;
- const SkIRect* r = node->fRect;
- for (;;) {
- if (r->fTop > currY) {
- nextY = SkMin32(nextY, r->fTop);
- break;
- }
- edges = append_rect(edges, *r);
- nextY = SkMin32(nextY, r->fBottom);
- node = node->fNext;
- r = node->fRect;
- }
- int edgeCount = edges - edgeStorage.get();
- edges = edgeStorage.get();
- SkASSERT(edgeCount <= count * 2);
-
- SkQSort(edges, edgeCount, sizeof(edges[0]), compare_vedge);
- accum.append(nextY, edges, edgeCount);
-
- RNode* prev = NULL;
- node = nodeHead;
- while (node->fRect->fTop <= currY) {
- RNode* next = node->fNext;
- if (node->fRect->fBottom <= nextY) {
- // drop this rect from our linklist
- SkASSERT(node->fRect->fBottom == nextY);
- if (prev) {
- prev->fNext = next;
- } else {
- nodeHead = next;
- }
- } else {
- prev = node;
- }
- node = next;
+ this->setEmpty();
+ } else {
+ this->setRect(rects[0]);
+ for (int i = 1; i < count; i++) {
+ this->op(rects[i], kUnion_Op);
}
- currY = nextY;
}
-
- SkAutoTArray<RunType> runs(accum.count());
- accum.copyTo(runs.get());
- return this->setRuns(runs.get(), accum.count());
+ return !this->isEmpty();
}
///////////////////////////////////////////////////////////////////////////////
diff --git a/xcode/effects/effects.xcodeproj/project.pbxproj b/xcode/effects/effects.xcodeproj/project.pbxproj
index 238b6a528d..6030f4b573 100644
--- a/xcode/effects/effects.xcodeproj/project.pbxproj
+++ b/xcode/effects/effects.xcodeproj/project.pbxproj
@@ -352,10 +352,7 @@
1DEB91F108733DB70010E9CD /* Release */ = {
isa = XCBuildConfiguration;
buildSettings = {
- ARCHS = (
- ppc,
- i386,
- );
+ ARCHS = "$(NATIVE_ARCH)";
GCC_ENABLE_CPP_EXCEPTIONS = NO;
GCC_ENABLE_CPP_RTTI = NO;
GCC_PREPROCESSOR_DEFINITIONS = SK_RELEASE;
@@ -392,7 +389,7 @@
GCC_WARN_UNUSED_VALUE = YES;
GCC_WARN_UNUSED_VARIABLE = YES;
PREBINDING = NO;
- SDKROOT = /Developer/SDKs/MacOSX10.4u.sdk;
+ SDKROOT = "";
USER_HEADER_SEARCH_PATHS = "../../include/**";
WARNING_CFLAGS = "";
};
diff --git a/xcode/maccore/maccore.xcodeproj/project.pbxproj b/xcode/maccore/maccore.xcodeproj/project.pbxproj
index 13b8a5ae08..65c9990890 100644
--- a/xcode/maccore/maccore.xcodeproj/project.pbxproj
+++ b/xcode/maccore/maccore.xcodeproj/project.pbxproj
@@ -14,10 +14,10 @@
002884E10EFABFFC0083E387 /* SkGlobals_global.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 002884E00EFABFFC0083E387 /* SkGlobals_global.cpp */; };
003144D50FB8491400B10956 /* SkImageDecoder_CG.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27739F2E0F11409100F233EA /* SkImageDecoder_CG.cpp */; };
00488AF40F86532E00C08A57 /* SkDebug_stdio.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00488AF30F86532E00C08A57 /* SkDebug_stdio.cpp */; };
- 0049ACCF10F66A1400A5AECA /* SkFontHost_mac.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7BEE0F01427100A2D6EE /* SkFontHost_mac.cpp */; };
007C8DC910B4694D008CDB57 /* SkUtils_opts_none.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007C8DC810B4694D008CDB57 /* SkUtils_opts_none.cpp */; };
27739F2B0F11407000F233EA /* SkCreateCGImageRef.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27739F2A0F11407000F233EA /* SkCreateCGImageRef.cpp */; };
27739F2D0F11408100F233EA /* SkImageDecoder.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27739F2C0F11408100F233EA /* SkImageDecoder.cpp */; };
+ 27D0F42F11BD234C001B8EBE /* SkFontHost_mac_atsui.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27D0F41B11BD227D001B8EBE /* SkFontHost_mac_atsui.cpp */; };
/* End PBXBuildFile section */
/* Begin PBXFileReference section */
@@ -30,11 +30,12 @@
002884A40EFAB5DE0083E387 /* SkTime_Unix.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkTime_Unix.cpp; path = ../../src/ports/SkTime_Unix.cpp; sourceTree = SOURCE_ROOT; };
002884E00EFABFFC0083E387 /* SkGlobals_global.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkGlobals_global.cpp; path = ../../src/ports/SkGlobals_global.cpp; sourceTree = SOURCE_ROOT; };
00488AF30F86532E00C08A57 /* SkDebug_stdio.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkDebug_stdio.cpp; path = ../../src/ports/SkDebug_stdio.cpp; sourceTree = SOURCE_ROOT; };
- 007A7BEE0F01427100A2D6EE /* SkFontHost_mac.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkFontHost_mac.cpp; path = ../../src/ports/SkFontHost_mac.cpp; sourceTree = SOURCE_ROOT; };
007C8DC810B4694D008CDB57 /* SkUtils_opts_none.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkUtils_opts_none.cpp; path = ../../src/opts/SkUtils_opts_none.cpp; sourceTree = SOURCE_ROOT; };
27739F2A0F11407000F233EA /* SkCreateCGImageRef.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkCreateCGImageRef.cpp; path = ../../src/utils/mac/SkCreateCGImageRef.cpp; sourceTree = SOURCE_ROOT; };
27739F2C0F11408100F233EA /* SkImageDecoder.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkImageDecoder.cpp; path = ../../src/images/SkImageDecoder.cpp; sourceTree = SOURCE_ROOT; };
27739F2E0F11409100F233EA /* SkImageDecoder_CG.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkImageDecoder_CG.cpp; path = ../../src/ports/SkImageDecoder_CG.cpp; sourceTree = SOURCE_ROOT; };
+ 27D0F41B11BD227D001B8EBE /* SkFontHost_mac_atsui.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkFontHost_mac_atsui.cpp; path = ../../src/ports/SkFontHost_mac_atsui.cpp; sourceTree = SOURCE_ROOT; };
+ 27D0F41C11BD227D001B8EBE /* SkFontHost_mac_coretext.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkFontHost_mac_coretext.cpp; path = ../../src/ports/SkFontHost_mac_coretext.cpp; sourceTree = SOURCE_ROOT; };
D2AAC046055464E500DB518D /* libmaccore.a */ = {isa = PBXFileReference; explicitFileType = archive.ar; includeInIndex = 0; path = libmaccore.a; sourceTree = BUILT_PRODUCTS_DIR; };
/* End PBXFileReference section */
@@ -74,13 +75,14 @@
08FB7795FE84155DC02AAC07 /* Source */ = {
isa = PBXGroup;
children = (
+ 27D0F41B11BD227D001B8EBE /* SkFontHost_mac_atsui.cpp */,
+ 27D0F41C11BD227D001B8EBE /* SkFontHost_mac_coretext.cpp */,
007C8DC810B4694D008CDB57 /* SkUtils_opts_none.cpp */,
00488AF30F86532E00C08A57 /* SkDebug_stdio.cpp */,
002884E00EFABFFC0083E387 /* SkGlobals_global.cpp */,
002884A20EFAB5DE0083E387 /* SkOSFile_stdio.cpp */,
002884A30EFAB5DE0083E387 /* SkThread_pthread.cpp */,
002884A40EFAB5DE0083E387 /* SkTime_Unix.cpp */,
- 007A7BEE0F01427100A2D6EE /* SkFontHost_mac.cpp */,
);
name = Source;
sourceTree = "<group>";
@@ -173,7 +175,7 @@
00488AF40F86532E00C08A57 /* SkDebug_stdio.cpp in Sources */,
003144D50FB8491400B10956 /* SkImageDecoder_CG.cpp in Sources */,
007C8DC910B4694D008CDB57 /* SkUtils_opts_none.cpp in Sources */,
- 0049ACCF10F66A1400A5AECA /* SkFontHost_mac.cpp in Sources */,
+ 27D0F42F11BD234C001B8EBE /* SkFontHost_mac_atsui.cpp in Sources */,
);
runOnlyForDeploymentPostprocessing = 0;
};
@@ -226,10 +228,7 @@
1DEB91F108733DB70010E9CD /* Release */ = {
isa = XCBuildConfiguration;
buildSettings = {
- ARCHS = (
- ppc,
- i386,
- );
+ ARCHS = "$(NATIVE_ARCH)";
GCC_ENABLE_CPP_EXCEPTIONS = NO;
GCC_ENABLE_CPP_RTTI = NO;
GCC_PREPROCESSOR_DEFINITIONS = (
@@ -241,7 +240,7 @@
GCC_WARN_UNUSED_VARIABLE = YES;
HEADER_SEARCH_PATHS = "/opt/local/include/**";
PREBINDING = NO;
- SDKROOT = /Developer/SDKs/MacOSX10.4u.sdk;
+ SDKROOT = "";
USER_HEADER_SEARCH_PATHS = "../../include//**";
};
name = Release;
diff --git a/xcode/sampleapp/SampleApp.xcodeproj/project.pbxproj b/xcode/sampleapp/SampleApp.xcodeproj/project.pbxproj
index 2e75566ee2..911486d700 100644
--- a/xcode/sampleapp/SampleApp.xcodeproj/project.pbxproj
+++ b/xcode/sampleapp/SampleApp.xcodeproj/project.pbxproj
@@ -32,7 +32,6 @@
0001FB98110E362F00C1D647 /* SkGLState.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0001FB91110E362F00C1D647 /* SkGLState.cpp */; };
0001FB99110E362F00C1D647 /* SkGLTextCache.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0001FB92110E362F00C1D647 /* SkGLTextCache.cpp */; };
0001FB9A110E362F00C1D647 /* SkTextureCache.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0001FB93110E362F00C1D647 /* SkTextureCache.cpp */; };
- 000630AD10F4E8F000BC2C23 /* SampleText.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 000630AC10F4E8EF00BC2C23 /* SampleText.cpp */; };
001B871E1042184D00C84ED4 /* Forth.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 001B871D1042184D00C84ED4 /* Forth.cpp */; };
0021F3A21120B29C0062682F /* SkStaticTextView.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0021F3A11120B29C0062682F /* SkStaticTextView.cpp */; };
0021F3D31120B61F0062682F /* SampleUnitMapper.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00995E1510A079D80054AD6D /* SampleUnitMapper.cpp */; };
@@ -42,11 +41,9 @@
00244DCD106A630100B8F4D8 /* bitmapfilters.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00244DC7106A630100B8F4D8 /* bitmapfilters.cpp */; };
00244DE2106A681600B8F4D8 /* SampleShaders.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CA80F01658C00A2D6EE /* SampleShaders.cpp */; };
00281C751083CF7E00BCCB06 /* libAnimator.a in Frameworks */ = {isa = PBXBuildFile; fileRef = 00281C711083CF6600BCCB06 /* libAnimator.a */; };
- 00281C781083CFA100BCCB06 /* SampleAnimator.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00281C771083CFA100BCCB06 /* SampleAnimator.cpp */; };
00281D071084ED1200BCCB06 /* SkXMLParser_expat.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00281D061084ED1200BCCB06 /* SkXMLParser_expat.cpp */; };
0028847B0EFAB46A0083E387 /* libcore.a in Frameworks */ = {isa = PBXBuildFile; fileRef = 002884510EFAA35C0083E387 /* libcore.a */; };
002884BD0EFAB6A30083E387 /* libmaccore.a in Frameworks */ = {isa = PBXBuildFile; fileRef = 002884BC0EFAB69F0083E387 /* libmaccore.a */; };
- 003EE652111239D5001AB759 /* SampleWarp.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 003EE651111239D5001AB759 /* SampleWarp.cpp */; };
0041CDDB0F00975E00695E8C /* SampleImageDir.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0041CDDA0F00975E00695E8C /* SampleImageDir.cpp */; };
0041CDF30F009ED100695E8C /* SkImageRef.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0041CDF20F009ED100695E8C /* SkImageRef.cpp */; };
0041CDF60F009EED00695E8C /* SkImageRef_GlobalPool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0041CDF50F009EED00695E8C /* SkImageRef_GlobalPool.cpp */; };
@@ -66,7 +63,6 @@
00575A1810BB02CF00A43B94 /* SampleEffects.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00FF39130FC6ED2C00915187 /* SampleEffects.cpp */; };
00575A3B10BB05FE00A43B94 /* SampleArc.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00A41E4A0EFC312F00C9CBEB /* SampleArc.cpp */; };
00575A9510BB2FF600A43B94 /* SampleMipMap.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 2794C04E0FE72903009AD112 /* SampleMipMap.cpp */; };
- 005778B40FF5616F00582CD9 /* SampleShapes.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 003145310FB9B48F00B10956 /* SampleShapes.cpp */; };
005E92DC0FF08507008965B9 /* SampleFilter2.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0041CE290F00A12400695E8C /* SampleFilter2.cpp */; };
005E92E00FF08512008965B9 /* SampleFilter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0041CE280F00A12400695E8C /* SampleFilter.cpp */; };
0061BC9310D6787A0079EBE5 /* SampleGradients.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00C55DA00F8552DC000CAC09 /* SampleGradients.cpp */; };
@@ -75,10 +71,7 @@
007A7CB40F01658C00A2D6EE /* SamplePoints.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CA50F01658C00A2D6EE /* SamplePoints.cpp */; };
007A7CB60F01658C00A2D6EE /* SampleRegion.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CA70F01658C00A2D6EE /* SampleRegion.cpp */; };
007A7CB80F01658C00A2D6EE /* SampleStrokeText.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CA90F01658C00A2D6EE /* SampleStrokeText.cpp */; };
- 007A7CBB0F01658C00A2D6EE /* SampleTextAlpha.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CAC0F01658C00A2D6EE /* SampleTextAlpha.cpp */; };
- 007A7CBC0F01658C00A2D6EE /* SampleTextEffects.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CAD0F01658C00A2D6EE /* SampleTextEffects.cpp */; };
007A7CBD0F01658C00A2D6EE /* SampleTextOnPath.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CAE0F01658C00A2D6EE /* SampleTextOnPath.cpp */; };
- 007A7CC00F01658C00A2D6EE /* SampleVertices.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CB10F01658C00A2D6EE /* SampleVertices.cpp */; };
00840B75104C69F5005B3EDC /* SampleExtractAlpha.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 00840B74104C69F5005B3EDC /* SampleExtractAlpha.cpp */; };
0086CBF110A8661F00C8BF27 /* SampleAvoid.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0086CBF010A8661F00C8BF27 /* SampleAvoid.cpp */; };
0086CC1C10A9B6A600C8BF27 /* SamplePicture.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CA40F01658C00A2D6EE /* SamplePicture.cpp */; };
@@ -104,8 +97,43 @@
01FC44D507BD3BB800D228F4 /* Quartz.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 01FC44D407BD3BB800D228F4 /* Quartz.framework */; };
27005D16100903C100E275B6 /* SampleLines.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0041CE2E0F00A12400695E8C /* SampleLines.cpp */; };
27005D5F10095B2B00E275B6 /* SampleCircle.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 0041CE200F00A12400695E8C /* SampleCircle.cpp */; };
+ 27433F1E11A1874A0045AD84 /* SampleSVG.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB9B119B32670017B155 /* SampleSVG.cpp */; };
+ 27433F3311A18EA60045AD84 /* SampleTextEffects.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CAD0F01658C00A2D6EE /* SampleTextEffects.cpp */; };
+ 27433F4911A1D24E0045AD84 /* SampleMessages.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27433F4811A1D24E0045AD84 /* SampleMessages.cpp */; };
+ 275E801611AAC2FF0051C03A /* SampleShapes.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 003145310FB9B48F00B10956 /* SampleShapes.cpp */; };
+ 275E802311AAC3330051C03A /* SampleVertices.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CB10F01658C00A2D6EE /* SampleVertices.cpp */; };
2762F66D0FCCCABE002BD8B4 /* SkFlipPixelRef.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 2762F66B0FCCCABE002BD8B4 /* SkFlipPixelRef.cpp */; };
2762F66E0FCCCABE002BD8B4 /* SkPageFlipper.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 2762F66C0FCCCABE002BD8B4 /* SkPageFlipper.cpp */; };
+ 27CAAB65119B303E0017B155 /* SkSVGCircle.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB30119B303E0017B155 /* SkSVGCircle.cpp */; };
+ 27CAAB66119B303E0017B155 /* SkSVGClipPath.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB32119B303E0017B155 /* SkSVGClipPath.cpp */; };
+ 27CAAB67119B303E0017B155 /* SkSVGDefs.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB34119B303E0017B155 /* SkSVGDefs.cpp */; };
+ 27CAAB68119B303E0017B155 /* SkSVGElements.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB36119B303E0017B155 /* SkSVGElements.cpp */; };
+ 27CAAB69119B303E0017B155 /* SkSVGEllipse.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB38119B303E0017B155 /* SkSVGEllipse.cpp */; };
+ 27CAAB6A119B303E0017B155 /* SkSVGFeColorMatrix.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB3A119B303E0017B155 /* SkSVGFeColorMatrix.cpp */; };
+ 27CAAB6B119B303E0017B155 /* SkSVGFilter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB3C119B303E0017B155 /* SkSVGFilter.cpp */; };
+ 27CAAB6C119B303E0017B155 /* SkSVGG.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB3E119B303E0017B155 /* SkSVGG.cpp */; };
+ 27CAAB6D119B303E0017B155 /* SkSVGGradient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB40119B303E0017B155 /* SkSVGGradient.cpp */; };
+ 27CAAB6E119B303E0017B155 /* SkSVGGroup.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB42119B303E0017B155 /* SkSVGGroup.cpp */; };
+ 27CAAB6F119B303E0017B155 /* SkSVGImage.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB44119B303E0017B155 /* SkSVGImage.cpp */; };
+ 27CAAB70119B303E0017B155 /* SkSVGLine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB46119B303E0017B155 /* SkSVGLine.cpp */; };
+ 27CAAB71119B303E0017B155 /* SkSVGLinearGradient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB48119B303E0017B155 /* SkSVGLinearGradient.cpp */; };
+ 27CAAB72119B303E0017B155 /* SkSVGMask.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB4A119B303E0017B155 /* SkSVGMask.cpp */; };
+ 27CAAB73119B303E0017B155 /* SkSVGMetadata.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB4C119B303E0017B155 /* SkSVGMetadata.cpp */; };
+ 27CAAB74119B303E0017B155 /* SkSVGPaintState.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB4E119B303E0017B155 /* SkSVGPaintState.cpp */; };
+ 27CAAB75119B303E0017B155 /* SkSVGParser.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB4F119B303E0017B155 /* SkSVGParser.cpp */; };
+ 27CAAB76119B303E0017B155 /* SkSVGPath.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB50119B303E0017B155 /* SkSVGPath.cpp */; };
+ 27CAAB77119B303E0017B155 /* SkSVGPolygon.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB52119B303E0017B155 /* SkSVGPolygon.cpp */; };
+ 27CAAB78119B303E0017B155 /* SkSVGPolyline.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB54119B303E0017B155 /* SkSVGPolyline.cpp */; };
+ 27CAAB79119B303E0017B155 /* SkSVGRadialGradient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB56119B303E0017B155 /* SkSVGRadialGradient.cpp */; };
+ 27CAAB7A119B303E0017B155 /* SkSVGRect.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB58119B303E0017B155 /* SkSVGRect.cpp */; };
+ 27CAAB7B119B303E0017B155 /* SkSVGStop.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB5A119B303E0017B155 /* SkSVGStop.cpp */; };
+ 27CAAB7C119B303E0017B155 /* SkSVGSVG.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB5C119B303E0017B155 /* SkSVGSVG.cpp */; };
+ 27CAAB7D119B303E0017B155 /* SkSVGSymbol.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB5E119B303E0017B155 /* SkSVGSymbol.cpp */; };
+ 27CAAB7E119B303E0017B155 /* SkSVGText.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB60119B303E0017B155 /* SkSVGText.cpp */; };
+ 27CAAB7F119B303E0017B155 /* SkSVGUse.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB62119B303E0017B155 /* SkSVGUse.cpp */; };
+ 27CAAB96119B321A0017B155 /* SkXMLWriter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 27CAAB95119B321A0017B155 /* SkXMLWriter.cpp */; };
+ 27D0F3C311BD2012001B8EBE /* SampleText.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 000630AC10F4E8EF00BC2C23 /* SampleText.cpp */; };
+ 27EC817811982E1300481B56 /* SampleTextAlpha.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 007A7CAC0F01658C00A2D6EE /* SampleTextAlpha.cpp */; };
8D0C4E8D0486CD37000505A6 /* InfoPlist.strings in Resources */ = {isa = PBXBuildFile; fileRef = 0867D6AAFE840B52C02AAC07 /* InfoPlist.strings */; };
8D0C4E8E0486CD37000505A6 /* main.nib in Resources */ = {isa = PBXBuildFile; fileRef = 02345980000FD03B11CA0E72 /* main.nib */; };
8D0C4E920486CD37000505A6 /* Carbon.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 20286C33FDCF999611CA2CEA /* Carbon.framework */; };
@@ -211,7 +239,6 @@
00281C661083CF5100BCCB06 /* SkTextBox.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkTextBox.cpp; path = ../../src/views/SkTextBox.cpp; sourceTree = SOURCE_ROOT; };
00281C691083CF6600BCCB06 /* Animator.xcodeproj */ = {isa = PBXFileReference; lastKnownFileType = "wrapper.pb-project"; name = Animator.xcodeproj; path = ../Animator/Animator.xcodeproj; sourceTree = SOURCE_ROOT; };
00281C771083CFA100BCCB06 /* SampleAnimator.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SampleAnimator.cpp; path = ../../samplecode/SampleAnimator.cpp; sourceTree = SOURCE_ROOT; };
- 00281CAA1083D2C800BCCB06 /* test.xml */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text.xml; name = test.xml; path = /skimages/test.xml; sourceTree = "<absolute>"; };
00281D061084ED1200BCCB06 /* SkXMLParser_expat.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkXMLParser_expat.cpp; path = ../../src/ports/SkXMLParser_expat.cpp; sourceTree = SOURCE_ROOT; };
002884490EFAA35C0083E387 /* core.xcodeproj */ = {isa = PBXFileReference; lastKnownFileType = "wrapper.pb-project"; name = core.xcodeproj; path = ../core/core.xcodeproj; sourceTree = SOURCE_ROOT; };
002884B40EFAB69F0083E387 /* maccore.xcodeproj */ = {isa = PBXFileReference; lastKnownFileType = "wrapper.pb-project"; name = maccore.xcodeproj; path = ../maccore/maccore.xcodeproj; sourceTree = SOURCE_ROOT; };
@@ -280,6 +307,7 @@
0867D6ABFE840B52C02AAC07 /* English */ = {isa = PBXFileReference; fileEncoding = 10; lastKnownFileType = text.plist.strings; name = English; path = English.lproj/InfoPlist.strings; sourceTree = "<group>"; };
1870340FFE93FCAF11CA0CD7 /* English */ = {isa = PBXFileReference; lastKnownFileType = wrapper.nib; name = English; path = English.lproj/main.nib; sourceTree = "<group>"; };
20286C33FDCF999611CA2CEA /* Carbon.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = Carbon.framework; path = /System/Library/Frameworks/Carbon.framework; sourceTree = "<absolute>"; };
+ 27433F4811A1D24E0045AD84 /* SampleMessages.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SampleMessages.cpp; path = ../../tetrark/SampleMessages.cpp; sourceTree = SOURCE_ROOT; };
2762F66B0FCCCABE002BD8B4 /* SkFlipPixelRef.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkFlipPixelRef.cpp; path = ../../src/images/SkFlipPixelRef.cpp; sourceTree = SOURCE_ROOT; };
2762F66C0FCCCABE002BD8B4 /* SkPageFlipper.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkPageFlipper.cpp; path = ../../src/images/SkPageFlipper.cpp; sourceTree = SOURCE_ROOT; };
2762F6740FCCCB01002BD8B4 /* SampleAll.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SampleAll.cpp; path = ../../samplecode/SampleAll.cpp; sourceTree = SOURCE_ROOT; };
@@ -288,6 +316,63 @@
2762F6780FCCCB01002BD8B4 /* SamplePolyToPoly.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SamplePolyToPoly.cpp; path = ../../samplecode/SamplePolyToPoly.cpp; sourceTree = SOURCE_ROOT; };
2762F6790FCCCB01002BD8B4 /* SampleTests.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SampleTests.cpp; path = ../../samplecode/SampleTests.cpp; sourceTree = SOURCE_ROOT; };
2794C04E0FE72903009AD112 /* SampleMipMap.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SampleMipMap.cpp; path = ../../samplecode/SampleMipMap.cpp; sourceTree = SOURCE_ROOT; };
+ 27A34E8B119892DD00860515 /* SampleTextBox.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SampleTextBox.cpp; path = ../../samplecode/SampleTextBox.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB2F119B303E0017B155 /* SkSVG.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVG.cpp; path = ../../src/svg/SkSVG.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB30119B303E0017B155 /* SkSVGCircle.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGCircle.cpp; path = ../../src/svg/SkSVGCircle.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB31119B303E0017B155 /* SkSVGCircle.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGCircle.h; path = ../../src/svg/SkSVGCircle.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB32119B303E0017B155 /* SkSVGClipPath.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGClipPath.cpp; path = ../../src/svg/SkSVGClipPath.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB33119B303E0017B155 /* SkSVGClipPath.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGClipPath.h; path = ../../src/svg/SkSVGClipPath.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB34119B303E0017B155 /* SkSVGDefs.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGDefs.cpp; path = ../../src/svg/SkSVGDefs.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB35119B303E0017B155 /* SkSVGDefs.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGDefs.h; path = ../../src/svg/SkSVGDefs.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB36119B303E0017B155 /* SkSVGElements.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGElements.cpp; path = ../../src/svg/SkSVGElements.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB37119B303E0017B155 /* SkSVGElements.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGElements.h; path = ../../src/svg/SkSVGElements.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB38119B303E0017B155 /* SkSVGEllipse.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGEllipse.cpp; path = ../../src/svg/SkSVGEllipse.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB39119B303E0017B155 /* SkSVGEllipse.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGEllipse.h; path = ../../src/svg/SkSVGEllipse.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB3A119B303E0017B155 /* SkSVGFeColorMatrix.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGFeColorMatrix.cpp; path = ../../src/svg/SkSVGFeColorMatrix.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB3B119B303E0017B155 /* SkSVGFeColorMatrix.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGFeColorMatrix.h; path = ../../src/svg/SkSVGFeColorMatrix.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB3C119B303E0017B155 /* SkSVGFilter.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGFilter.cpp; path = ../../src/svg/SkSVGFilter.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB3D119B303E0017B155 /* SkSVGFilter.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGFilter.h; path = ../../src/svg/SkSVGFilter.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB3E119B303E0017B155 /* SkSVGG.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGG.cpp; path = ../../src/svg/SkSVGG.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB3F119B303E0017B155 /* SkSVGG.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGG.h; path = ../../src/svg/SkSVGG.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB40119B303E0017B155 /* SkSVGGradient.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGGradient.cpp; path = ../../src/svg/SkSVGGradient.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB41119B303E0017B155 /* SkSVGGradient.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGGradient.h; path = ../../src/svg/SkSVGGradient.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB42119B303E0017B155 /* SkSVGGroup.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGGroup.cpp; path = ../../src/svg/SkSVGGroup.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB43119B303E0017B155 /* SkSVGGroup.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGGroup.h; path = ../../src/svg/SkSVGGroup.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB44119B303E0017B155 /* SkSVGImage.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGImage.cpp; path = ../../src/svg/SkSVGImage.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB45119B303E0017B155 /* SkSVGImage.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGImage.h; path = ../../src/svg/SkSVGImage.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB46119B303E0017B155 /* SkSVGLine.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGLine.cpp; path = ../../src/svg/SkSVGLine.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB47119B303E0017B155 /* SkSVGLine.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGLine.h; path = ../../src/svg/SkSVGLine.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB48119B303E0017B155 /* SkSVGLinearGradient.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGLinearGradient.cpp; path = ../../src/svg/SkSVGLinearGradient.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB49119B303E0017B155 /* SkSVGLinearGradient.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGLinearGradient.h; path = ../../src/svg/SkSVGLinearGradient.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB4A119B303E0017B155 /* SkSVGMask.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGMask.cpp; path = ../../src/svg/SkSVGMask.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB4B119B303E0017B155 /* SkSVGMask.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGMask.h; path = ../../src/svg/SkSVGMask.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB4C119B303E0017B155 /* SkSVGMetadata.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGMetadata.cpp; path = ../../src/svg/SkSVGMetadata.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB4D119B303E0017B155 /* SkSVGMetadata.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGMetadata.h; path = ../../src/svg/SkSVGMetadata.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB4E119B303E0017B155 /* SkSVGPaintState.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGPaintState.cpp; path = ../../src/svg/SkSVGPaintState.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB4F119B303E0017B155 /* SkSVGParser.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGParser.cpp; path = ../../src/svg/SkSVGParser.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB50119B303E0017B155 /* SkSVGPath.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGPath.cpp; path = ../../src/svg/SkSVGPath.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB51119B303E0017B155 /* SkSVGPath.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGPath.h; path = ../../src/svg/SkSVGPath.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB52119B303E0017B155 /* SkSVGPolygon.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGPolygon.cpp; path = ../../src/svg/SkSVGPolygon.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB53119B303E0017B155 /* SkSVGPolygon.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGPolygon.h; path = ../../src/svg/SkSVGPolygon.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB54119B303E0017B155 /* SkSVGPolyline.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGPolyline.cpp; path = ../../src/svg/SkSVGPolyline.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB55119B303E0017B155 /* SkSVGPolyline.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGPolyline.h; path = ../../src/svg/SkSVGPolyline.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB56119B303E0017B155 /* SkSVGRadialGradient.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGRadialGradient.cpp; path = ../../src/svg/SkSVGRadialGradient.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB57119B303E0017B155 /* SkSVGRadialGradient.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGRadialGradient.h; path = ../../src/svg/SkSVGRadialGradient.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB58119B303E0017B155 /* SkSVGRect.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGRect.cpp; path = ../../src/svg/SkSVGRect.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB59119B303E0017B155 /* SkSVGRect.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGRect.h; path = ../../src/svg/SkSVGRect.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB5A119B303E0017B155 /* SkSVGStop.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGStop.cpp; path = ../../src/svg/SkSVGStop.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB5B119B303E0017B155 /* SkSVGStop.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGStop.h; path = ../../src/svg/SkSVGStop.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB5C119B303E0017B155 /* SkSVGSVG.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGSVG.cpp; path = ../../src/svg/SkSVGSVG.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB5D119B303E0017B155 /* SkSVGSVG.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGSVG.h; path = ../../src/svg/SkSVGSVG.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB5E119B303E0017B155 /* SkSVGSymbol.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGSymbol.cpp; path = ../../src/svg/SkSVGSymbol.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB5F119B303E0017B155 /* SkSVGSymbol.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGSymbol.h; path = ../../src/svg/SkSVGSymbol.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB60119B303E0017B155 /* SkSVGText.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGText.cpp; path = ../../src/svg/SkSVGText.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB61119B303E0017B155 /* SkSVGText.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGText.h; path = ../../src/svg/SkSVGText.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB62119B303E0017B155 /* SkSVGUse.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkSVGUse.cpp; path = ../../src/svg/SkSVGUse.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB63119B303E0017B155 /* SkSVGUse.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SkSVGUse.h; path = ../../src/svg/SkSVGUse.h; sourceTree = SOURCE_ROOT; };
+ 27CAAB95119B321A0017B155 /* SkXMLWriter.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SkXMLWriter.cpp; path = ../../src/xml/SkXMLWriter.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAAB9B119B32670017B155 /* SampleSVG.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = SampleSVG.cpp; path = ../../samplecode/SampleSVG.cpp; sourceTree = SOURCE_ROOT; };
+ 27CAB350119C9C4C0017B155 /* colorfont.xml */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text.xml; name = colorfont.xml; path = /colorfont.xml; sourceTree = "<absolute>"; };
32DBCF6D0370B57F00C91783 /* CICarbonSample_Prefix.pch */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CICarbonSample_Prefix.pch; sourceTree = "<group>"; };
4A9504C8FFE6A3BC11CA0CBA /* ApplicationServices.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = ApplicationServices.framework; path = /System/Library/Frameworks/ApplicationServices.framework; sourceTree = "<absolute>"; };
4A9504CAFFE6A41611CA0CBA /* CoreServices.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = CoreServices.framework; path = /System/Library/Frameworks/CoreServices.framework; sourceTree = "<absolute>"; };
@@ -319,8 +404,11 @@
isa = PBXGroup;
children = (
003EE651111239D5001AB759 /* SampleWarp.cpp */,
+ 27A34E8B119892DD00860515 /* SampleTextBox.cpp */,
000630AC10F4E8EF00BC2C23 /* SampleText.cpp */,
00281C771083CFA100BCCB06 /* SampleAnimator.cpp */,
+ 27CAB350119C9C4C0017B155 /* colorfont.xml */,
+ 27CAAB9B119B32670017B155 /* SampleSVG.cpp */,
0086CBF010A8661F00C8BF27 /* SampleAvoid.cpp */,
00A729630FD93ED600D5051F /* SampleTestGL.cpp */,
2762F6740FCCCB01002BD8B4 /* SampleAll.cpp */,
@@ -485,14 +573,15 @@
20286C29FDCF999611CA2CEA /* CICarbonSample */ = {
isa = PBXGroup;
children = (
+ 27CAAB2E119B30240017B155 /* SVG */,
0001FB8C110E360A00C1D647 /* opengl */,
- 00281CAA1083D2C800BCCB06 /* test.xml */,
00244DC5106A62E600B8F4D8 /* gm */,
001B871D1042184D00C84ED4 /* Forth.cpp */,
00ED55F2104A10EB00F51FF8 /* StdWords.cpp */,
00EB4592104DBB18002B413E /* ForthTests.cpp */,
00BB289A104781D00057BF7E /* SampleForth.cpp */,
00003C620EFC22A8000FF73A /* SampleApp.cpp */,
+ 27433F4811A1D24E0045AD84 /* SampleMessages.cpp */,
2762F66A0FCCCAA2002BD8B4 /* images */,
00003C6A0EFC22AD000FF73A /* views */,
00281C7B1083CFB700BCCB06 /* xml */,
@@ -556,6 +645,67 @@
name = images;
sourceTree = "<group>";
};
+ 27CAAB2E119B30240017B155 /* SVG */ = {
+ isa = PBXGroup;
+ children = (
+ 27CAAB95119B321A0017B155 /* SkXMLWriter.cpp */,
+ 27CAAB2F119B303E0017B155 /* SkSVG.cpp */,
+ 27CAAB30119B303E0017B155 /* SkSVGCircle.cpp */,
+ 27CAAB31119B303E0017B155 /* SkSVGCircle.h */,
+ 27CAAB32119B303E0017B155 /* SkSVGClipPath.cpp */,
+ 27CAAB33119B303E0017B155 /* SkSVGClipPath.h */,
+ 27CAAB34119B303E0017B155 /* SkSVGDefs.cpp */,
+ 27CAAB35119B303E0017B155 /* SkSVGDefs.h */,
+ 27CAAB36119B303E0017B155 /* SkSVGElements.cpp */,
+ 27CAAB37119B303E0017B155 /* SkSVGElements.h */,
+ 27CAAB38119B303E0017B155 /* SkSVGEllipse.cpp */,
+ 27CAAB39119B303E0017B155 /* SkSVGEllipse.h */,
+ 27CAAB3A119B303E0017B155 /* SkSVGFeColorMatrix.cpp */,
+ 27CAAB3B119B303E0017B155 /* SkSVGFeColorMatrix.h */,
+ 27CAAB3C119B303E0017B155 /* SkSVGFilter.cpp */,
+ 27CAAB3D119B303E0017B155 /* SkSVGFilter.h */,
+ 27CAAB3E119B303E0017B155 /* SkSVGG.cpp */,
+ 27CAAB3F119B303E0017B155 /* SkSVGG.h */,
+ 27CAAB40119B303E0017B155 /* SkSVGGradient.cpp */,
+ 27CAAB41119B303E0017B155 /* SkSVGGradient.h */,
+ 27CAAB42119B303E0017B155 /* SkSVGGroup.cpp */,
+ 27CAAB43119B303E0017B155 /* SkSVGGroup.h */,
+ 27CAAB44119B303E0017B155 /* SkSVGImage.cpp */,
+ 27CAAB45119B303E0017B155 /* SkSVGImage.h */,
+ 27CAAB46119B303E0017B155 /* SkSVGLine.cpp */,
+ 27CAAB47119B303E0017B155 /* SkSVGLine.h */,
+ 27CAAB48119B303E0017B155 /* SkSVGLinearGradient.cpp */,
+ 27CAAB49119B303E0017B155 /* SkSVGLinearGradient.h */,
+ 27CAAB4A119B303E0017B155 /* SkSVGMask.cpp */,
+ 27CAAB4B119B303E0017B155 /* SkSVGMask.h */,
+ 27CAAB4C119B303E0017B155 /* SkSVGMetadata.cpp */,
+ 27CAAB4D119B303E0017B155 /* SkSVGMetadata.h */,
+ 27CAAB4E119B303E0017B155 /* SkSVGPaintState.cpp */,
+ 27CAAB4F119B303E0017B155 /* SkSVGParser.cpp */,
+ 27CAAB50119B303E0017B155 /* SkSVGPath.cpp */,
+ 27CAAB51119B303E0017B155 /* SkSVGPath.h */,
+ 27CAAB52119B303E0017B155 /* SkSVGPolygon.cpp */,
+ 27CAAB53119B303E0017B155 /* SkSVGPolygon.h */,
+ 27CAAB54119B303E0017B155 /* SkSVGPolyline.cpp */,
+ 27CAAB55119B303E0017B155 /* SkSVGPolyline.h */,
+ 27CAAB56119B303E0017B155 /* SkSVGRadialGradient.cpp */,
+ 27CAAB57119B303E0017B155 /* SkSVGRadialGradient.h */,
+ 27CAAB58119B303E0017B155 /* SkSVGRect.cpp */,
+ 27CAAB59119B303E0017B155 /* SkSVGRect.h */,
+ 27CAAB5A119B303E0017B155 /* SkSVGStop.cpp */,
+ 27CAAB5B119B303E0017B155 /* SkSVGStop.h */,
+ 27CAAB5C119B303E0017B155 /* SkSVGSVG.cpp */,
+ 27CAAB5D119B303E0017B155 /* SkSVGSVG.h */,
+ 27CAAB5E119B303E0017B155 /* SkSVGSymbol.cpp */,
+ 27CAAB5F119B303E0017B155 /* SkSVGSymbol.h */,
+ 27CAAB60119B303E0017B155 /* SkSVGText.cpp */,
+ 27CAAB61119B303E0017B155 /* SkSVGText.h */,
+ 27CAAB62119B303E0017B155 /* SkSVGUse.cpp */,
+ 27CAAB63119B303E0017B155 /* SkSVGUse.h */,
+ );
+ name = SVG;
+ sourceTree = "<group>";
+ };
/* End PBXGroup section */
/* Begin PBXNativeTarget section */
@@ -695,10 +845,7 @@
0041CE4A0F00A12400695E8C /* SamplePatch.cpp in Sources */,
007A7CB40F01658C00A2D6EE /* SamplePoints.cpp in Sources */,
007A7CB80F01658C00A2D6EE /* SampleStrokeText.cpp in Sources */,
- 007A7CBB0F01658C00A2D6EE /* SampleTextAlpha.cpp in Sources */,
- 007A7CBC0F01658C00A2D6EE /* SampleTextEffects.cpp in Sources */,
007A7CBD0F01658C00A2D6EE /* SampleTextOnPath.cpp in Sources */,
- 007A7CC00F01658C00A2D6EE /* SampleVertices.cpp in Sources */,
0041CE3C0F00A12400695E8C /* SampleEncode.cpp in Sources */,
009CC9190F65918A002185BE /* SampleFontScalerTest.cpp in Sources */,
008C4D980F77DAEE0056981C /* SampleHairline.cpp in Sources */,
@@ -712,7 +859,6 @@
00AF787E0FE94433007F9650 /* SamplePath.cpp in Sources */,
005E92DC0FF08507008965B9 /* SampleFilter2.cpp in Sources */,
005E92E00FF08512008965B9 /* SampleFilter.cpp in Sources */,
- 005778B40FF5616F00582CD9 /* SampleShapes.cpp in Sources */,
27005D16100903C100E275B6 /* SampleLines.cpp in Sources */,
27005D5F10095B2B00E275B6 /* SampleCircle.cpp in Sources */,
00C1B809103857A400FA5948 /* SampleFillType.cpp in Sources */,
@@ -728,7 +874,6 @@
00244DBB106A61B700B8F4D8 /* SampleGM.cpp in Sources */,
00244DCD106A630100B8F4D8 /* bitmapfilters.cpp in Sources */,
00244DE2106A681600B8F4D8 /* SampleShaders.cpp in Sources */,
- 00281C781083CFA100BCCB06 /* SampleAnimator.cpp in Sources */,
00281D071084ED1200BCCB06 /* SkXMLParser_expat.cpp in Sources */,
009230D8109F111F00AD3F12 /* OverView.cpp in Sources */,
00995E0E10A078E30054AD6D /* SkCubicInterval.cpp in Sources */,
@@ -743,7 +888,6 @@
0061BC9310D6787A0079EBE5 /* SampleGradients.cpp in Sources */,
0061BCC910D696730079EBE5 /* SampleTiling.cpp in Sources */,
0061BCD910D951AA0079EBE5 /* SkTextBox.cpp in Sources */,
- 000630AD10F4E8F000BC2C23 /* SampleText.cpp in Sources */,
0001FB78110E33CC00C1D647 /* SampleTestGL.cpp in Sources */,
0001FB94110E362F00C1D647 /* SkGL.cpp in Sources */,
0001FB95110E362F00C1D647 /* SkGLCanvas.cpp in Sources */,
@@ -752,9 +896,43 @@
0001FB98110E362F00C1D647 /* SkGLState.cpp in Sources */,
0001FB99110E362F00C1D647 /* SkGLTextCache.cpp in Sources */,
0001FB9A110E362F00C1D647 /* SkTextureCache.cpp in Sources */,
- 003EE652111239D5001AB759 /* SampleWarp.cpp in Sources */,
0021F3A21120B29C0062682F /* SkStaticTextView.cpp in Sources */,
0021F3D31120B61F0062682F /* SampleUnitMapper.cpp in Sources */,
+ 27EC817811982E1300481B56 /* SampleTextAlpha.cpp in Sources */,
+ 27CAAB65119B303E0017B155 /* SkSVGCircle.cpp in Sources */,
+ 27CAAB66119B303E0017B155 /* SkSVGClipPath.cpp in Sources */,
+ 27CAAB67119B303E0017B155 /* SkSVGDefs.cpp in Sources */,
+ 27CAAB68119B303E0017B155 /* SkSVGElements.cpp in Sources */,
+ 27CAAB69119B303E0017B155 /* SkSVGEllipse.cpp in Sources */,
+ 27CAAB6A119B303E0017B155 /* SkSVGFeColorMatrix.cpp in Sources */,
+ 27CAAB6B119B303E0017B155 /* SkSVGFilter.cpp in Sources */,
+ 27CAAB6C119B303E0017B155 /* SkSVGG.cpp in Sources */,
+ 27CAAB6D119B303E0017B155 /* SkSVGGradient.cpp in Sources */,
+ 27CAAB6E119B303E0017B155 /* SkSVGGroup.cpp in Sources */,
+ 27CAAB6F119B303E0017B155 /* SkSVGImage.cpp in Sources */,
+ 27CAAB70119B303E0017B155 /* SkSVGLine.cpp in Sources */,
+ 27CAAB71119B303E0017B155 /* SkSVGLinearGradient.cpp in Sources */,
+ 27CAAB72119B303E0017B155 /* SkSVGMask.cpp in Sources */,
+ 27CAAB73119B303E0017B155 /* SkSVGMetadata.cpp in Sources */,
+ 27CAAB74119B303E0017B155 /* SkSVGPaintState.cpp in Sources */,
+ 27CAAB75119B303E0017B155 /* SkSVGParser.cpp in Sources */,
+ 27CAAB76119B303E0017B155 /* SkSVGPath.cpp in Sources */,
+ 27CAAB77119B303E0017B155 /* SkSVGPolygon.cpp in Sources */,
+ 27CAAB78119B303E0017B155 /* SkSVGPolyline.cpp in Sources */,
+ 27CAAB79119B303E0017B155 /* SkSVGRadialGradient.cpp in Sources */,
+ 27CAAB7A119B303E0017B155 /* SkSVGRect.cpp in Sources */,
+ 27CAAB7B119B303E0017B155 /* SkSVGStop.cpp in Sources */,
+ 27CAAB7C119B303E0017B155 /* SkSVGSVG.cpp in Sources */,
+ 27CAAB7D119B303E0017B155 /* SkSVGSymbol.cpp in Sources */,
+ 27CAAB7E119B303E0017B155 /* SkSVGText.cpp in Sources */,
+ 27CAAB7F119B303E0017B155 /* SkSVGUse.cpp in Sources */,
+ 27CAAB96119B321A0017B155 /* SkXMLWriter.cpp in Sources */,
+ 27433F1E11A1874A0045AD84 /* SampleSVG.cpp in Sources */,
+ 27433F3311A18EA60045AD84 /* SampleTextEffects.cpp in Sources */,
+ 27433F4911A1D24E0045AD84 /* SampleMessages.cpp in Sources */,
+ 275E801611AAC2FF0051C03A /* SampleShapes.cpp in Sources */,
+ 275E802311AAC3330051C03A /* SampleVertices.cpp in Sources */,
+ 27D0F3C311BD2012001B8EBE /* SampleText.cpp in Sources */,
);
runOnlyForDeploymentPostprocessing = 0;
};
@@ -850,6 +1028,7 @@
buildSettings = {
GCC_ENABLE_CPP_EXCEPTIONS = NO;
GCC_ENABLE_CPP_RTTI = NO;
+ GCC_ENABLE_SYMBOL_SEPARATION = NO;
GCC_PREPROCESSOR_DEFINITIONS = (
SK_BUILD_FOR_MAC,
SK_DEBUG,
@@ -865,6 +1044,7 @@
/opt/local/lib,
);
OTHER_LDFLAGS = "-lexpat";
+ PRECOMPS_INCLUDE_HEADERS_FROM_BUILT_PRODUCTS_DIR = NO;
SDKROOT = "";
USER_HEADER_SEARCH_PATHS = "../../src/core ../../include/** ../../gm";
};
@@ -890,7 +1070,7 @@
/opt/local/lib,
);
OTHER_LDFLAGS = "-lexpat";
- SDKROOT = /Developer/SDKs/MacOSX10.4u.sdk;
+ SDKROOT = "";
USER_HEADER_SEARCH_PATHS = "../../src/core ../../include/** ../../gm";
};
name = Release;
diff --git a/src/ports/SkFontHost_mac_coretext.cpp b/src/ports/SkFontHost_mac_coretext.cpp
index 74c14b163e..2fc5c1dbbf 100644
--- a/src/ports/SkFontHost_mac_coretext.cpp
+++ b/src/ports/SkFontHost_mac_coretext.cpp
@@ -28,13 +28,12 @@
//============================================================================
// Constants
//----------------------------------------------------------------------------
-static const SkFontID kSkInvalidFontID = 0;
-
-static const size_t FONT_CACHE_MEMORY_BUDGET = 1024 * 1024;
-static const char *FONT_DEFAULT_NAME = "Lucida Sans";
-
+static const SkFontID kSkInvalidFontID = 0;
+static const size_t FONT_CACHE_MEMORY_BUDGET = 1024 * 1024;
+static const char FONT_DEFAULT_NAME[] = "Lucida Sans";
+static const float FONT_CANONICAL_POINTSIZE = 1.0f;
//============================================================================
@@ -255,7 +254,8 @@ CTFontRef SkNativeFontCache::CreateNativeFont(const SkString &theName, SkTypefac
// Create the font
//
// Fonts are scaled using the Sk matrix, so we always request a font of size 1.
if (cfFontName != NULL && cfFontTraits != NULL && cfAttributes != NULL && cfTraits != NULL)
{
CFDictionaryAddValue(cfTraits, kCTFontSymbolicTrait, cfFontTraits);
@@ -265,7 +265,7 @@ CTFontRef SkNativeFontCache::CreateNativeFont(const SkString &theName, SkTypefac
ctFontDesc = CTFontDescriptorCreateWithAttributes(cfAttributes);
if (ctFontDesc != NULL)
- ctFont = CTFontCreateWithFontDescriptor(ctFontDesc, 1.0, NULL);
+ ctFont = CTFontCreateWithFontDescriptor(ctFontDesc, FONT_CANONICAL_POINTSIZE, NULL);
}
@@ -353,12 +353,13 @@ SkScalerContext_Mac::SkScalerContext_Mac(const SkDescriptor* desc)
// Initialise ourselves
mColorSpace = CGColorSpaceCreateDeviceGray();
- mTransform = CGAffineTransformMake(SkScalarToFloat(skMatrix[SkMatrix::kMScaleX]),
- SkScalarToFloat(skMatrix[SkMatrix::kMSkewX]),
- SkScalarToFloat(skMatrix[SkMatrix::kMSkewY]),
- SkScalarToFloat(skMatrix[SkMatrix::kMScaleY]),
- SkScalarToFloat(skMatrix[SkMatrix::kMTransX]),
- SkScalarToFloat(skMatrix[SkMatrix::kMTransY]));
+ const float inv = 1.0f / FONT_CANONICAL_POINTSIZE;
+ mTransform = CGAffineTransformMake(SkScalarToFloat(skMatrix[SkMatrix::kMScaleX]) * inv,
+ -SkScalarToFloat(skMatrix[SkMatrix::kMSkewY]) * inv,
+ -SkScalarToFloat(skMatrix[SkMatrix::kMSkewX]) * inv,
+ SkScalarToFloat(skMatrix[SkMatrix::kMScaleY]) * inv,
+ SkScalarToFloat(skMatrix[SkMatrix::kMTransX]) * inv,
+ SkScalarToFloat(skMatrix[SkMatrix::kMTransY]) * inv);
mFont = CTFontCreateCopyWithAttributes(ctFont, 0.0, &mTransform, NULL);
mGlyphCount = (uint16_t) numGlyphs;
@@ -422,7 +423,6 @@ void SkScalerContext_Mac::generateMetrics(SkGlyph* glyph)
// to transform the bounding box ourselves.
//
// The bounds are also expanded by 1 pixel, to give CG room for anti-aliasing.
- theBounds = CGRectApplyAffineTransform(theBounds, mTransform);
theBounds = CGRectInset(theBounds, -1, -1);
@@ -442,7 +442,6 @@ void SkScalerContext_Mac::generateImage(const SkGlyph& glyph)
CGGlyph cgGlyph;
CGFontRef cgFont;
-
// Get the state we need
sk_bzero(glyph.fImage, glyph.fHeight * glyph.rowBytes());
@@ -451,53 +450,37 @@ void SkScalerContext_Mac::generateImage(const SkGlyph& glyph)
cgContext = CGBitmapContextCreate( glyph.fImage, glyph.fWidth, glyph.fHeight, 8,
glyph.rowBytes(), mColorSpace, kCGImageAlphaNone);
-
// Draw the glyph
- if (cgFont != NULL && cgContext != NULL)
- {
+ if (cgFont != NULL && cgContext != NULL) {
CGContextSetGrayFillColor( cgContext, 1.0, 1.0);
CGContextSetTextDrawingMode(cgContext, kCGTextFill);
CGContextSetFont( cgContext, cgFont);
- CGContextSetFontSize( cgContext, 1.0);
+ CGContextSetFontSize( cgContext, FONT_CANONICAL_POINTSIZE);
CGContextSetTextMatrix( cgContext, mTransform);
CGContextShowGlyphsAtPoint( cgContext, -glyph.fLeft, glyph.fTop + glyph.fHeight, &cgGlyph, 1);
- }
-
+ }
// Clean up
CFSafeRelease(cgFont);
CFSafeRelease(cgContext);
}
-void SkScalerContext_Mac::generatePath(const SkGlyph& glyph, SkPath* path)
-{ CGGlyph cgGlyph;
- CGPathRef cgPath;
-
-
- // Get the state we need
- cgGlyph = (CGGlyph) glyph.getGlyphID(fBaseGlyphCount);
- cgPath = CTFontCreatePathForGlyph(mFont, cgGlyph, NULL);
+void SkScalerContext_Mac::generatePath(const SkGlyph& glyph, SkPath* path) {
+ CGGlyph cgGlyph = (CGGlyph)glyph.getGlyphID(fBaseGlyphCount);
+ CGPathRef cgPath = CTFontCreatePathForGlyph(mFont, cgGlyph, NULL);
-
- // Get the path
path->reset();
-
- if (cgPath != NULL)
+ if (cgPath != NULL) {
CGPathApply(cgPath, path, SkScalerContext_Mac::CTPathElement);
-
- CFSafeRelease(cgPath);
+ CFRelease(cgPath);
+ }
}
-void SkScalerContext_Mac::generateFontMetrics(SkPaint::FontMetrics* mx, SkPaint::FontMetrics* my)
-{ SkPaint::FontMetrics theMetrics;
- CGRect theBounds;
-
-
- // Get the state we need
- theBounds = CTFontGetBoundingBox(mFont);
+void SkScalerContext_Mac::generateFontMetrics(SkPaint::FontMetrics* mx,
+ SkPaint::FontMetrics* my) {
+ CGRect theBounds = CTFontGetBoundingBox(mFont);
-
- // Get the metrics
+ SkPaint::FontMetrics theMetrics;
theMetrics.fTop = -CGRectGetMaxY(theBounds);
theMetrics.fAscent = -CTFontGetAscent(mFont);
theMetrics.fDescent = CTFontGetDescent(mFont);
@@ -508,8 +491,7 @@ void SkScalerContext_Mac::generateFontMetrics(SkPaint::FontMetrics* mx, SkPaint:
theMetrics.fXMax = CGRectGetMaxX(theBounds);
theMetrics.fXHeight = CTFontGetXHeight(mFont);
-
- // Return the metrics
+#if 0
SkASSERT(theMetrics.fTop <= 0.0);
SkASSERT(theMetrics.fAscent <= 0.0);
SkASSERT(theMetrics.fDescent >= 0.0);
@@ -519,12 +501,14 @@ void SkScalerContext_Mac::generateFontMetrics(SkPaint::FontMetrics* mx, SkPaint:
SkASSERT(theMetrics.fXMin <= 0.0);
SkASSERT(theMetrics.fXMax > 0.0);
SkASSERT(theMetrics.fXHeight >= 0.0);
+#endif
- if (mx != NULL)
+ if (mx != NULL) {
*mx = theMetrics;
-
- if (my != NULL)
+ }
+ if (my != NULL) {
*my = theMetrics;
+ }
}
void SkScalerContext_Mac::CTPathElement(void *info, const CGPathElement *element)
@@ -585,6 +569,7 @@ SkTypeface* SkFontHost::CreateTypeface(const SkTypeface* familyFace,
// Clone an existing typeface
+ // TODO: only clone if style matches the familyFace's style...
if (familyName == NULL && familyFace != NULL)
{
familyFace->ref();
@@ -592,6 +577,9 @@ SkTypeface* SkFontHost::CreateTypeface(const SkTypeface* familyFace,
}
+ if (fontName.isEmpty()) {
+ fontName.set(FONT_DEFAULT_NAME);
+ }
// Get the native font
fontInfo = fontTable->GetFontInfo(fontName, style);
if (fontInfo.fontID == kSkInvalidFontID)
@@ -605,14 +593,14 @@ SkTypeface* SkFontHost::CreateTypeface(const SkTypeface* familyFace,
SkTypeface* SkFontHost::CreateTypefaceFromStream(SkStream* stream)
{
- SkASSERT(!"SkFontHost::CreateTypefaceFromStream unimplemented");
- return(NULL);
+// SkASSERT(!"SkFontHost::CreateTypefaceFromStream unimplemented");
+ return SkFontHost::CreateTypeface(NULL, NULL, NULL, NULL, SkTypeface::kNormal);
}
SkTypeface* SkFontHost::CreateTypefaceFromFile(const char path[])
{
- SkASSERT(!"SkFontHost::CreateTypefaceFromFile unimplemented");
- return(NULL);
+// SkASSERT(!"SkFontHost::CreateTypefaceFromFile unimplemented");
+ return SkFontHost::CreateTypeface(NULL, NULL, NULL, NULL, SkTypeface::kNormal);
}
///////////////////////////////////////////////////////////////////////////
@@ -255,7 +254,8 @@ CTFontRef SkNativeFontCache::CreateNativeFont(const SkString &theName, SkTypefac
// Create the font
//
- // Fonts are scaled using the Sk matrix, so we always request a font of size 1.
+ // Fonts are scaled using the Sk matrix, so we always request a font
+ // at a canonical size FONT_CANONICAL_POINTSIZE
if (cfFontName != NULL && cfFontTraits != NULL && cfAttributes != NULL && cfTraits != NULL)
{